# Wipe Clean

![PyPI](https://img.shields.io/pypi/v/wipe-clean?logo=pypi)
![PyPI - Status](https://img.shields.io/pypi/status/wipe-clean?logo=pypi)
![PyPI - Downloads](https://img.shields.io/pypi/dm/wipe-clean?logo=pypi)

Clean your terminal in a ritual way. Works on Windows, Linux and macOS.

![demo](https://github.com/wenoptics/python-wipe-clean/blob/master/doc/terminal.gif?raw=true)


```bash
pip install wipe-clean
```

> `wipe-clean` requires Python 3.6.1 and above. Note that Python 3.6.0 is
 not supported due to lack of `NamedTuples` typing.


## Usage

```bash
wipe-clean
```


## Related Projects

- [`JeanJouliaCode/wipeclean`](https://github.com/JeanJouliaCode/wipeClean) (JavaScript)

  The animation part is a direct port of `JeanJouliaCode/wipeclean`.
